@@ -8,7 +8,7 @@ use base 'RxPerl::Subject';
 use Carp 'croak';
 use Scalar::Util 'weaken';
 
-our $VERSION = "v6.1.2";
+our $VERSION = "v6.2.0";
 
 sub _on_subscribe {
     my ($self, $subscriber) = @_;
@@ -28,7 +28,7 @@ sub new {
     weaken(my $w_self = $self);
     my $next_orig = $self->{next};
     $self->{next} = sub {
-        $w_self->{_last_value} = $_[0] unless $self->{_closed};
+        $w_self->{_last_value} = $_[0] unless $w_self->{_closed};
         $next_orig->(@_);
     };
 
